@@ -173,16 +173,19 @@ class MinioFS(FileSystem):
         return data
 
     def rm(self, paths):
+        """
+        :param paths:
+        """
         if type(paths) != list:
             raise TypeError("Invalid type: paths is not a list.")
-
         filenames = set(map(lambda x: '/'.join(x.split('/')[1:]), paths))
         bucket_unique = set((map(lambda x: x.split('/')[0], paths)))
         if len(bucket_unique) != 1:
             raise ValueError(f"Removing files across multiple buckets ({bucket_unique}) is not permitted.")
         else:
             bucket = bucket_unique.pop()
-        self.__client__.remove_objects(bucket_name=bucket, objects_iter=filenames)
+        for filename in filenames:
+            self.__client__.remove_object(bucket_name=bucket, object_name=filename)
 
 
 class LocalFS(FileSystem):
