@@ -124,9 +124,7 @@ def test_minio_stream_file(MinioFileSystem):
 
 def test_minio_rm(MinioFileSystem):
     MinioFileSystem.rm(["bucket/file1.txt", "bucket/file2.txt"])
-    MinioFileSystem.__client__.remove_objects.assert_called_once_with(bucket_name="bucket",
-                                                                      objects_iter={"file1.txt", "file2.txt"})
-
+    assert MinioFileSystem.__client__.remove_object.call_count == 2
 
 @mock.patch('miniMinio.FileSystem.LocalFS.ls')
 def test_local_lb(ls, LocalFileSystem):
